==> wedeliver_core-0.6.5-py3-none-any.whl: wedeliver_core/base.py <==
class WeDeliverCore:
    __app = None

    @staticmethod
    def get_app():
        """ Static access method. """
        if WeDeliverCore.__app == None:
            WeDeliverCore()
        return WeDeliverCore.__app

    def __init__(self, app=None):
        """ Virtually private constructor. """
        if WeDeliverCore.__app != None:
            raise Exception("This class is a singleton!")
        else:
            WeDeliverCore.__app = app
            setup_default_routes(app)


def setup_default_routes(app):
    from wedeliver_core.app_decorators.app_entry import route
    from wedeliver_core.helpers.fetch_relational_data import fetch_relational_data
    @route(
        path='/',
        require_auth=False
    )
    def _health_check_service():
        return dict(name="{} Service".format(app.config.get('SERVICE_NAME')), works=True)

    @route(
        path='/health_check',
        require_auth=False
    )
    def _health_check_with_path_service():
        return dict(name="{} Service".format(app.config.get('SERVICE_NAME')), works=True)

    @route("/fetch_relational_data", methods=["POST"], require_auth=False)
    def _fetch_relational_data_service(validated_data):
        """
        Swagger definition
        """
        user_data_key = '__user_auth_data__'
        if validated_data.get(user_data_key) is not None:
            from thrivve_core.helpers.auth import Auth
            Auth.set_user(validated_data.get(user_data_key))

        validated_data.pop(user_data_key)

        return fetch_relational_data(**validated_data)

==> wedeliver_core-0.6.7-py3-none-any.whl: wedeliver_core/base.py <==
class WeDeliverCore:
    __app = None

    @staticmethod
    def get_app():
        """ Static access method. """
        if WeDeliverCore.__app == None:
            WeDeliverCore()
        return WeDeliverCore.__app

    def __init__(self, app=None):
        """ Virtually private constructor. """
        if WeDeliverCore.__app != None:
            raise Exception("This class is a singleton!")
        else:
            WeDeliverCore.__app = app
            setup_default_routes(app)


def setup_default_routes(app):
    from wedeliver_core.app_decorators.app_entry import route
    from wedeliver_core.helpers.fetch_relational_data import fetch_relational_data
    @route(
        path='/',
        require_auth=False
    )
    def _health_check_service():
        return dict(name="{} Service".format(app.config.get('SERVICE_NAME')), works=True)

    @route(
        path='/health_check',
        require_auth=False
    )
    def _health_check_with_path_service():
        return dict(name="{} Service".format(app.config.get('SERVICE_NAME')), works=True)

    @route("/fetch_relational_data", methods=["POST"], require_auth=False)
    def _fetch_relational_data_service(validated_data):
        """
        Swagger definition
        """
        user_data_key = '__user_auth_data__'
        if validated_data.get(user_data_key) is not None:
            from wedeliver_core.helpers.auth import Auth
            Auth.set_user(validated_data.get(user_data_key))

        validated_data.pop(user_data_key, None)

        return fetch_relational_data(**validated_data)
